@@ -1,8 +1,8 @@
 #
 # Scan.pm
-# Last Modification: Tue Dec 21 18:06:09 WET 2004
+# Last Modification: Sat Feb 12 19:21:41 WET 2005
 #
-# Copyright (c) 2004 Henrique Dias <hdias@aesbuc.pt>. All rights reserved.
+# Copyright (c) 2005 Henrique Dias <hdias@aesbuc.pt>. All rights reserved.
 # This module is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -19,7 +19,7 @@ use SelfLoader;
 use vars qw($VERSION @ISA @EXPORT $ERROR $SKIPPED $SUSPICIOUS $CALLBACK);
 
 @ISA = qw(Exporter);
-$VERSION = '1.39';
+$VERSION = '1.40';
 
 ($ERROR, $SKIPPED, $SUSPICIOUS, $CALLBACK) = ("", 0, 0, "");
 
@@ -137,7 +137,7 @@ sub callback { $CALLBACK; }
 1;
 
 __DATA__
-# generated in: 2004/12/21 18:40:44
+# generated in: 2005/02/12 19:34:26
 
 sub get_app_sign {
 	$_ = pop;
@@ -510,6 +510,7 @@ sub scan_binary {
 				}
 				if($total==2048) {
 					/\x20\x03\x2b\x3a\x99\x12\x22\x80\x2b\x3e\xf7\x26\xe1\x36\x06\xc2\x40\x20\x91\x10\x58\xac\x14\x50\x54\x58\x0a\x0c\x05\x87\x48\x20\x84\x0d\xee\x40\x90\x10\x20\x2a\x23\xb6\x2a\x22\x1b\xda\x8b\x64\x10\x64\x8b\x37\x3f\x1b\x51\xb4\x1e\xc2\xa0\xa2\xa2\xa2\xa2\x22/s and $virus = "Exploit-DcomRpc.gen", last LINE;
+					/\x42\x6c\x61\x63\x6b\x57\x6f\x72\x6d/s and $virus = "W32/MyWife.b\@MM", last LINE;
 					/\x83\x00\x7c\x24\x08\x01\x75\x0a\xff\x74\x00\x24\x04\xe8\x0a\x00\x01\x30\x59\x00\x6a\x01\x58\xc2\x0c\x00\x55\x8b\x00\xec\x8b\x4d\x0c\x33\xc0\x49\x83\x00\xf9\x08\x77\x66\xff\x24\x8d\x8f\x16\x10/s and $virus = "W32/Netsky.ac\@MM", last LINE;
 					/\x4f\x54\x9a\xf6\xd9\xef\x93\xa0\x2a\xba\x53\x51\x93\xe5\x92\xb9\xc0\x2b\xa3\xf4\x1b\xd3\x6d\x80\x69\x91\xea\xec\x1b\x3d\xa3\x28\x02\x12\x0a\xc4\xa2\x2b\x13\x23\x7c\x82\xbf\xc7\x0c\xa4\x2e\xc1/s and $virus = "W32/Netsky.x\@MM", last LINE;
 					/\xe8\x9b\x03\x00\x00\x85\xc0\x75\x01\xc3\xa1\x0c\x48\x00\x10\x53\x33\xdb\x3b\xc3\x75\x17\x68\x00\x14\x00\x10\x68\xe0\x93\x04\x00\x53\x53\xff\x15\x28\x20\x00\x10\xa3\x0c\x48\x00\x10\x6a\x1c\x68\x20\x30\x00\x10\xe8\x27\x04\x00\x00\x6a\x10\x68\x40\x30/s and $virus = "W32/Fizzer.dll", last LINE;
